<?php

namespace EventPortal\Domain\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\ValueObjects\QuestionData;
use Illuminate\Support\Arr;
use Illuminate\Support\Collection;

class UpdateQuestions
{
    public function execute(Collection $questions, FormStepSection $formStepSection): void
    {
        self::deleteUnusedQuestions($questions, $formStepSection);

        $questions->each(static function (QuestionData $question) use ($formStepSection): void {
            $dbQuestion = Question::updateOrCreate(
                ['id' => $question->id],
                Arr::add($question->toArray(), 'form_step_section_id', $formStepSection->id)
            );

            (new UpdateValidations)->execute($question->validations, $dbQuestion, $question->required);

            (new UpdateOptions)->execute($question->options, $dbQuestion);
        });
    }

    private static function deleteUnusedQuestions(Collection $questions, FormStepSection $formStepSection): void
    {
        Question::query()
            ->whereNotIn('id', $questions->pluck('id'))
            ->forFormStepSection($formStepSection)
            ->delete();
    }
}
