<?php

namespace EventPortal\Domain\SignIn\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\MorphTo;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class SignIn extends Model implements AuditableInterface
{
    use Auditable;

    public const KEY = 'sign-in';

    protected $fillable = [
        'signed_in_at',
        'signed_out_at',
        'userable_id',
        'userable_type',
        'locationable_id',
        'locationable_type',
    ];

    protected $dates = [
        'signed_in_at',
        'signed_out_at',
    ];

    public function signInable(): MorphTo
    {
        return $this->morphTo();
    }

    public function locationable(): MorphTo
    {
        return $this->morphTo('locationable');
    }

    public function userable(): MorphTo
    {
        return $this->morphTo('userable');
    }

    public function signOut(): bool
    {
        return $this->update(['signed_out_at' => Carbon::now()]);
    }

    public function getSignedInAttribute(): bool
    {
        if ($this->signed_out_at === null) {
            return true;
        }

        return $this->signed_in_at->gt($this->signed_out_at);
    }

    public function scopeAtLocationable(Builder $query, Model $locationable): Builder
    {
        return $query->where([
            'locationable_id' => $locationable->id,
            'locationable_type' => get_class($locationable),
        ]);
    }

    public function scopeForUserable(Builder $query, Model $userable): Builder
    {
        return $query->where([
            'userable_id' => $userable->id,
            'userable_type' => get_class($userable),
        ]);
    }
}
