<?php

namespace EventPortal\Tests\Feature\Admin\Venue;

use EventPortal\Domain\Venue\Models\Venue;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class VenueRouteTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions, MatchesSnapshots;

    /** @test */
    public function can_get_index_route()
    {
        factory(Venue::class)
            ->state('has-address')
            ->create(['name' => 'Test Venue', 'website' => 'http://example.com']);

        $this
            ->assertMatchesJsonSnapshot(
                $this->actingAsSuperAdmin()->get(route('admin.venue.index'))->props()
            );
    }

    /** @test */
    public function can_view_venue()
    {
        $venue = factory(Venue::class)
            ->state('has-address')
            ->create(['name' => 'Test Venue', 'website' => 'http://example.com']);

        $venuePayload = $this->actingAsSuperAdmin()
            ->get(route('admin.venue.show', $venue))
            ->assertOk()
            ->props();

        $this->assertMatchesJsonSnapshot($venuePayload);
    }
}
